EventKind

Enum EventKind 

pub enum EventKind {
Show 48 variants AmbiguousExternalNamespaceError = 0, CircularDependency = 1, CircularReexportError = 2, Eval = 3, IllegalIdentifierAsNameError = 4, InvalidExportOptionError = 5, InvalidOptionError = 6, MissingExportError = 7, MissingGlobalName = 8, MissingNameOptionForIifeExport = 9, InvalidAnnotation = 10, MixedExports = 11, ParseError = 12, UnresolvedEntry = 13, UnresolvedImport = 14, FilenameConflict = 15, FilenameOutsideOutputDirectoryError = 16, FileNotFoundError = 17, AssignToImportError = 18, CommonJsVariableInEsm = 19, ImportIsUndefined = 20, UnsupportedFeatureError = 21, EmptyImportMeta = 22, JsonParseError = 23, IllegalReassignmentError = 24, InvalidDefineConfigError = 25, ResolveError = 26, UnhandleableError = 27, UnloadableDependencyError = 28, TransformError = 29, ToleratedTransform = 30, NapiError = 31, CannotCallNamespace = 32, ConfigurationFieldConflict = 33, PreferBuiltinFeature = 34, BundlerInitializeError = 35, PluginError = 36, AlreadyClosedError = 37, CouldNotCleanDirectory = 38, PluginTimings = 39, DuplicateShebang = 40, TsConfigError = 41, UnsupportedTsconfigOption = 42, RuntimeModuleSymbolNotFoundError = 43, IneffectiveDynamicImport = 45, RequireTlaError = 46, LargeBarrelModules = 47, SourcemapBroken = 48,
}

Variants



AmbiguousExternalNamespaceError = 0



CircularDependency = 1

Whether to emit warnings when detecting circular dependency.

Circular dependencies lead to a bigger bundle size and sometimes cause execution order issues and are better to avoid.

{@include ../docs/checks-circular-dependency.md}



CircularReexportError = 2



Eval = 3

Whether to emit warnings when detecting uses of direct evals.

See Avoiding Direct eval in Troubleshooting page for more details.



IllegalIdentifierAsNameError = 4



InvalidExportOptionError = 5



InvalidOptionError = 6



MissingExportError = 7



MissingGlobalName = 8

Whether to emit warnings when the output.globals option is missing when needed.

See output.globals.



MissingNameOptionForIifeExport = 9

Whether to emit warnings when the output.name option is missing when needed.

See output.name.



InvalidAnnotation = 10

Whether to emit warnings when a #__PURE__ / @__PURE__ annotation has no effect due to its position.

Annotations placed where they cannot annotate a call expression (e.g. before a non-call expression, before a statement declaration, or between an identifier and = in a variable declarator) are ignored by the parser. Matches Rollup’s INVALID_ANNOTATION log code.

By default, warnings are emitted only for local project files inside cwd and outside node_modules. Set this option to false to disable the warning entirely.



MixedExports = 11

Whether to emit warnings when the way to export values is ambiguous.

See output.exports.



ParseError = 12



UnresolvedEntry = 13

Whether to emit warnings when an entrypoint cannot be resolved.



UnresolvedImport = 14

Whether to emit warnings when an import cannot be resolved.



FilenameConflict = 15

Whether to emit warnings when files generated have the same name with different contents.

{@include ../docs/checks-filename-conflict.md}



FilenameOutsideOutputDirectoryError = 16



FileNotFoundError = 17



AssignToImportError = 18



CommonJsVariableInEsm = 19

Whether to emit warnings when a CommonJS variable is used in an ES module.

CommonJS variables like module and exports are treated as global variables in ES modules and may not work as expected.

{@include ../docs/checks-commonjs-variable-in-esm.md}



ImportIsUndefined = 20

Whether to emit warnings when an imported variable is not exported.

If the code is importing a variable that is not exported by the imported module, the value will always be undefined. This might be a mistake in the code.

{@include ../docs/checks-import-is-undefined.md}



UnsupportedFeatureError = 21



EmptyImportMeta = 22

Whether to emit warnings when import.meta is not supported with the output format and is replaced with an empty object ({}).

See import.meta in Non-ESM Output Formats page for more details.



JsonParseError = 23



IllegalReassignmentError = 24



InvalidDefineConfigError = 25



ResolveError = 26



UnhandleableError = 27



UnloadableDependencyError = 28



TransformError = 29



ToleratedTransform = 30



NapiError = 31



CannotCallNamespace = 32

Whether to emit warnings when a namespace is called as a function.

A module namespace object is an object and not a function. Calling it as a function will cause a runtime error.

{@include ../docs/checks-cannot-call-namespace.md}



ConfigurationFieldConflict = 33

Whether to emit warnings when a config value is overridden by another config value with a higher priority.

{@include ../docs/checks-configuration-field-conflict.md}



PreferBuiltinFeature = 34

Whether to emit warnings when a plugin that is covered by a built-in feature is used.

Using built-in features is generally more performant than using plugins.



BundlerInitializeError = 35



PluginError = 36



AlreadyClosedError = 37



CouldNotCleanDirectory = 38

Whether to emit warnings when Rolldown could not clean the output directory.

See output.cleanDir.



PluginTimings = 39

Whether to emit warnings when plugins take significant time during the build process.

{@include ../docs/checks-plugin-timings.md}



DuplicateShebang = 40

Whether to emit warnings when both the code and postBanner contain shebang

Having multiple shebangs in a file is a syntax error.



TsConfigError = 41



UnsupportedTsconfigOption = 42

Whether to emit warnings when a tsconfig option or combination of options is not supported.



RuntimeModuleSymbolNotFoundError = 43



IneffectiveDynamicImport = 45

Whether to emit warnings when a module is dynamically imported but also statically imported, making the dynamic import ineffective for code splitting.



RequireTlaError = 46



LargeBarrelModules = 47

Whether to emit info logs when a barrel module has a very large number of re-exports (more than 5000).

Such modules can significantly slow down module resolution. Consider using @rolldown/plugin-transform-imports to rewrite barrel imports at the source level so the barrel file is never loaded.

See Large barrel modules for more details.



SourcemapBroken = 48

Whether to emit warnings when a plugin transforms code without generating a sourcemap.